import { Component, OnInit, OnDestroy, Renderer2, ElementRef, ViewChild } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { IonicModule, AlertController } from '@ionic/angular';
import { openThrowDriftBottleModal } from '../throw-drift-bottle/throw-drift-bottle.component';
import { ModalController } from '@ionic/angular/standalone';
import { HttpClient } from '@angular/common/http';
import { CloudObject, CloudQuery } from 'src/lib/ncloud';
import { UserService } from 'src/app/user.service'; // 假设这是你的用户服务
import { CommonModule } from '@angular/common'; // 导入 CommonModule

@Component({
  selector: 'app-drift-bottle',
  templateUrl: './drift-bottle.component.html',
  styleUrls: ['./drift-bottle.component.scss'],
  standalone: true,
  imports: [
    IonicModule,
    CommonModule, // 添加 CommonModule
    // 其他导入项...
  ]
})
export class DriftBottleComponent implements OnInit, OnDestroy {
  @ViewChild('backgroundAudio', { static: false }) audioElement!: ElementRef<HTMLAudioElement>;

  constructor(
    private router: Router,
    private modalCtrl: ModalController,
    private route: ActivatedRoute,
    private http: HttpClient,
    private renderer: Renderer2,
    private userService: UserService, // 注入用户服务
    private alertController: AlertController // 注入 AlertController
  ) {}

  ngOnInit() {
    this.route.params.subscribe(data => {
      if (this.audioElement && this.audioElement.nativeElement) {
        const audio = this.audioElement.nativeElement;
        audio.loop = true;
        audio.play().catch((error: any) => {
          console.error('Failed to play audio:', error);
        });
      } else {
        console.warn('Audio element not found');
      }

      let listenLeaveInt = setInterval(() => {
        let isLeave = location.pathname?.indexOf("drift-bottle") == -1;
        if (isLeave) {
          this.stop();
          clearInterval(listenLeaveInt);
        }
      }, 500);
    });
  }

  ngOnDestroy() {
    this.stop();
  }

  stop() {
    if (this.audioElement && this.audioElement.nativeElement) {
      const audio = this.audioElement.nativeElement;
      audio.pause();
      audio.currentTime = 0; // 重置音频时间
      console.log('Audio element paused and reset');
    } else {
      console.warn('Audio element not found during destroy');
    }
    console.log('ngOnDestroy called');
  }

  throwDriftBottleModal() {
    openThrowDriftBottleModal(this.modalCtrl);
  }

  async catchDriftBottle() {
    const query = new CloudQuery("Driftbottle");
    query.equalTo("status", "drifting");

    try {
      const driftingBottles = await query.find();

      if (driftingBottles.length === 0) {
        this.presentAlert('失败', '没捞到…');
        return;
      }

      const randomIndex = Math.floor(Math.random() * driftingBottles.length);
      const bottleToCatch = driftingBottles[randomIndex];

      const username = this.userService.getUsername(); // 获取当前用户的用户名
      if (!username) {
        console.error('用户未登录或未找到用户名');
        this.presentAlert('错误', '用户未登录，请先登录。');
        return;
      }

      // 使用对象来设置多个字段
      bottleToCatch.set({
        status: "caught",
        catcher: username,
        catchtime: new Date()
      });

      await bottleToCatch.save();
      this.presentAlert('成功', '捞到啦！快去看看吧！');
    } catch (err) {
      console.error('获取漂流瓶时出错:', err);
      this.presentAlert('错误', '发生错误，请重试。');
    }
  }

  async presentAlert(header: string, message: string) {
    const alert = await this.alertController.create({
      header: header,
      message: message,
      buttons: ['OK']
    });

    await alert.present();
  }

  goMydriftbottle() {
    this.router.navigate(['tabs/my-drift-bottle']);
  }
}